==> gpss-1.02-src.zip: jp/wda/gpss/SocketProcessor.java <==
package jp.wda.gpss;

import jp.wda.gpss.system.AttributeContainer;
import jp.wda.gpss.system.InitParamContainer;

/**
 *	NCAg\PbgC^[tF[X
 *
 * @version	1.00007	2003/06/08
 * @since		1.00		2003/04/29
 * @author	amoi
 */
public interface SocketProcessor extends InitParamContainer, AttributeContainer{
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAg̃NCAgID擾܂B<BR>
	 * NCAgID́Aڑ̑SNCAgɑ΂AӂȕƂȂ܂B
	 * 
	 * @return NCAgID
	 */
	public String getClientID();
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\Pbg̎gpGR[fBO擾܂B<BR>
	 * GR[fBÓAݒt@CŎw肳܂B
	 * 
	 * @return GR[fBO
	 */
	public String getEncoding();
	
	/* ***********************************************************************>> */;
	/**
	 * setUserName(String s)\bhŔCӂ̃[UɕύXȂA
	 * p[^Ŏw肳ꂽ[U[擾܂B<BR>
	 * 
	 * @return [U[
	 */
	public String getUserName();
	/**
	 * [U[ݒ肵܂B<BR>
	 * 
	 * @param s ݒl<BR>
	 */
	public void setUserName(String s);
	
	/* ***********************************************************************>> */;
	/**
	 * setPassword(String s)\bhŔCӂ̃pX[hɕύXȂA
	 * p[^Ŏw肳ꂽpX[h擾܂B<BR>
	 * @return pX[h
	 */
	public String getPassword();
	/**
	 * pX[hݒ肵܂B<BR>
	 * @param s ݒl<BR>
	 */
	public void setPassword(String s);
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgIPAhX擾܂B<BR>
	 * 
	 * @return IPAhX
	 */
	public String getIPAddress();
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgɃbZ[W𑗂܂B<BR>
	 * bZ[Wnull"\0"I[Ƃ܂B<BR>
	 *
	 * @param msg NCAgɑ郁bZ[W
	 * @return Mɐꍇ͐^Asꍇ͋U
	 */
	public boolean send(String message);
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgIɏI܂B
	 */
	public void terminate();
	/**
	 * ̃\PbggpĂNCAgɏIbZ[WoA\PbgIɏI܂B
	 * @param message IbZ[W
	 */
	public void terminate(String message);
	/**
	 * ̃\PbggpĂNCAgɏIĂ邩mF܂B
	 * @param message ɏIĂꍇ͐^
	 */
	public boolean isTerminated();
}

==> gpss-1.04.02-src.zip: jp/wda/gpss/SocketProcessor.java <==
package jp.wda.gpss;

import jp.wda.gpss.system.AttributeContainer;
import jp.wda.gpss.system.InitParamContainer;

/**
 *	NCAg\PbgC^[tF[X
 *
 * @version	1.03		2003/09/18
 * @since		1.00		2003/04/29
 * @author	amoi
 */
public interface SocketProcessor extends InitParamContainer, AttributeContainer{
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAg̃NCAgID擾܂B<BR>
	 * NCAgID́Aڑ̑SNCAgɑ΂AӂȕƂȂ܂B
	 * 
	 * @return NCAgID
	 */
	public String getClientID();
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\Pbg̎gpGR[fBO擾܂B<BR>
	 * GR[fBÓAݒt@CŎw肳܂B
	 * 
	 * @return GR[fBO
	 */
	public String getEncoding();
	
	/* ***********************************************************************>> */;
	/**
	 * setUserName(String s)\bhŔCӂ̃[UɕύXȂA
	 * p[^Ŏw肳ꂽ[U[擾܂B<BR>
	 * 
	 * @return [U[
	 */
	public String getUserName();
	/**
	 * [U[ݒ肵܂B<BR>
	 * 
	 * @param s ݒl<BR>
	 */
	public void setUserName(String s);
	
	/* ***********************************************************************>> */;
	/**
	 * setPassword(String s)\bhŔCӂ̃pX[hɕύXȂA
	 * p[^Ŏw肳ꂽpX[h擾܂B<BR>
	 * @return pX[h
	 */
	public String getPassword();
	/**
	 * pX[hݒ肵܂B<BR>
	 * @param s ݒl<BR>
	 */
	public void setPassword(String s);
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgIPAhX擾܂B<BR>
	 * 
	 * @return IPAhX
	 */
	public String getIPAddress();
	
	/* ***********************************************************************>> */;
	/**
	 * ̃NCAgSockletݒ肵܂B<BR>
	 * @param s ݒl<BR>
	 * @see jp.wda.gpss.system.Main#doInitialCommand(SocketProcessorBase, String)
	 * @since 1.03
	 */
	public void setApplication(Socklet s);
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgɃbZ[W𑗂܂B<BR>
	 * bZ[Wnull"\0"I[Ƃ܂B<BR>
	 *
	 * @param message NCAgɑ郁bZ[W
	 * @return Mɐꍇ͐^Asꍇ͋U
	 */
	public boolean send(String message);
	
	/* ***********************************************************************>> */;
	/**
	 * ̃\PbggpĂNCAgIɏI܂B
	 */
	public void terminate();
	/**
	 * ̃\PbggpĂNCAgɏIbZ[WoA\PbgIɏI܂B
	 * @param message IbZ[W
	 */
	public void terminate(String message);
	/**
	 * ̃\PbggpĂNCAgɏIĂ邩mF܂B
	 * @return ɏIĂꍇ͐^
	 */
	public boolean isTerminated();
}
